@@ -2,6 +2,7 @@ import uuid
 
 import numpy as np
 import trimesh
+from trimesh import PointCloud
 
 from skrobot.coordinates.base import CascadedCoords
 from skrobot.coordinates.base import Coordinates
@@ -177,6 +178,39 @@ class Annulus(Link):
                                       visual_mesh=mesh)
 
 
+class LineString(Link):
+
+    def __init__(self,
+                 points,
+                 color=None,
+                 pos=(0, 0, 0),
+                 rot=np.eye(3),
+                 name=None):
+
+        if not isinstance(points, np.ndarray):
+            raise TypeError("points must be np.ndarray")
+
+        assert points.ndim == 2
+        assert points.shape[0] > 1, "points must be more than 1"
+        assert points.shape[1] == 3, "each point must be 3 dim"
+
+        if color is not None:
+            assert len(color) in (3, 4), "color must be RGB or RGBA"
+            colors = [color]
+        else:
+            colors = None
+
+        if name is None:
+            name = 'linestring_{}'.format(str(uuid.uuid1()).replace('-', '_'))
+        mesh = trimesh.load_path(points, colors=colors)
+        super(LineString, self).__init__(
+            pos=pos,
+            rot=rot,
+            name=name,
+            collision_mesh=None,
+            visual_mesh=mesh)
+
+
 class MeshLink(Link):
 
     def __init__(self,
@@ -206,11 +240,24 @@ class MeshLink(Link):
 class PointCloudLink(Link):
 
     def __init__(self,
-                 visual_mesh=None,
+                 point_cloud_like=None,
                  pos=(0, 0, 0), rot=np.eye(3), name=None):
+
+        accep_types = (type(None), np.ndarray, PointCloud)
+        if not isinstance(point_cloud_like, accep_types):
+            message = "point cloud must be either of {}".format(accep_types)
+            raise TypeError(message)
+
+        if isinstance(point_cloud_like, np.ndarray):
+            assert point_cloud_like.ndim == 2
+            assert point_cloud_like.shape[1] == 3
+            pcloud_mesh = PointCloud(point_cloud_like)
+        else:
+            pcloud_mesh = point_cloud_like
+
         if name is None:
             name = 'pointcloudlink_{}'.format(
                 str(uuid.uuid1()).replace('-', '_'))
 
         super(PointCloudLink, self).__init__(pos=pos, rot=rot, name=name)
-        self.visual_mesh = visual_mesh
+        self.visual_mesh = pcloud_mesh
