@@ -1,6 +1,5 @@
 from __future__ import division
 
-import hashlib
 from logging import getLogger
 from math import floor
 import os
@@ -12,16 +11,40 @@ from scipy.interpolate import RegularGridInterpolator
 from skrobot.coordinates import CascadedCoords
 from skrobot.coordinates import make_cascoords
 from skrobot.coordinates import Transform
+from skrobot.data import get_cache_dir
+from skrobot.utils import checksum_md5
 
 
 logger = getLogger(__name__)
 
 
-def trimesh2sdf(mesh, dim_grid):
+def trimesh2sdf(mesh, dim_grid=100, padding_grid=5):
+    """Convert trimesh to signed distance function.
+
+    Parameters
+    ----------
+    mesh : trimesh.base.Trimesh
+        mesh object.
+    dim_grid : int
+        dimension of the GridSDF.
+        This value is used for a not primitive mesh.
+    padding_grid : int
+        number of padding.
+
+    Returns
+    -------
+    sdf : skrobot.sdf.SignedDistanceFunction
+        converted signed distance function.
+    """
+    if not ('file_path' in mesh.metadata
+            or 'shape' in mesh.metadata):
+        raise ValueError("Input mesh doesn't contain valid metadata"
+                         " for converting SDF.")
     is_loaded_mesh = 'file_path' in mesh.metadata
     if is_loaded_mesh:
         file_path = mesh.metadata['file_path']
-        sdf = GridSDF.from_objfile(file_path, dim_grid=dim_grid)
+        sdf = GridSDF.from_objfile(file_path, dim_grid=dim_grid,
+                                   padding_grid=padding_grid)
     else:
         # process primtives
         shape = mesh.metadata['shape']
@@ -460,15 +483,8 @@ class GridSDF(SignedDistanceFunction):
 
             # resolution of the grid cells in original mesh coords
             resolution = float(f.readline())
-            sdf_data = np.zeros(dims)
-
-            # loop through file, getting each value
-            count = 0
-            for k in range(nz):
-                for j in range(ny):
-                    for i in range(nx):
-                        sdf_data[i][j][k] = float(f.readline())
-                        count += 1
+            sdf_data = np.fromstring(f.read(), dtype=float, sep='\n').reshape(
+                *dims).transpose(2, 1, 0)
         return GridSDF(sdf_data, origin, resolution)
 
     @staticmethod
@@ -495,14 +511,12 @@ class GridSDF(SignedDistanceFunction):
         sdf_instance : skrobot.sdf.GridSDF
             instance of sdf
         """
-
-        home_dir = os.path.expanduser('~')
-        sdf_cache_dir = os.path.join(home_dir, '.skrobot', 'sdf')
+        sdf_cache_dir = os.path.join(get_cache_dir(), 'sdf')
         if not os.path.exists(sdf_cache_dir):
             os.makedirs(sdf_cache_dir)
 
-        filename, extension = os.path.splitext(str(obj_filepath))
-        hashed_filename = hashlib.md5(filename.encode()).hexdigest()
+        hashed_filename = '{}_{}_{}'.format(
+            checksum_md5(obj_filepath), dim_grid, padding_grid)
 
         sdf_cache_path = os.path.join(sdf_cache_dir, hashed_filename + '.sdf')
         if not os.path.exists(sdf_cache_path):
