@@ -4,13 +4,13 @@
 import copy
 import os
 import time
+
+
 try:
     # for python3
-    from functools import lru_cache
     from urllib.parse import urlparse
 except ImportError:
     # for python2
-    from repoze.lru import lru_cache
     from urlparse import urlparse
 
 from lxml import etree as ET
@@ -23,6 +23,8 @@ import trimesh
 from skrobot.coordinates import normalize_vector
 from skrobot.coordinates import rpy_angle
 from skrobot.coordinates import rpy_matrix
+from skrobot.pycompat import lru_cache
+
 
 try:
     import rospkg
@@ -2379,6 +2381,7 @@ class Link(URDFType):
                             S[:3, :3] = np.diag(c.geometry.mesh.scale)
                             pose = pose.dot(S)
                     m.apply_transform(pose)
+                    m.metadata["origin"] = pose
                     meshes.append(m)
             if len(meshes) == 0:
                 return None
